@@ -47,7 +47,7 @@ class SignatureCheckerMeta(type):
             for baseClass in baseClasses:
                 try:
                     fBase = getattr(baseClass, methodName).__func__
-                    if not inspect.getargspec(f) == inspect.getargspec(fBase):
+                    if not inspect.getfullargspec(f) == inspect.getfullargspec(fBase):
                         raise BadSignatureException(str(methodName))
                 except AttributeError:
                     # This method was not defined in this base class,
@@ -87,31 +87,14 @@ try:
             Rohit Bhattacharya, Ashok Sivakumar, Collin Tokheim, Violeta Beleva Guthrie, Valsamo Anagnostou,
             Victor E. Velculescu, Rachel Karchin (2017) bioRxiv
         """
-        __alleles = frozenset(
-            ["HLA-A*01:01", "HLA-A*02:01", "HLA-A*02:02", "HLA-A*02:03", "HLA-A*02:04", "HLA-A*02:05", "HLA-A*02:06",
-             "HLA-A*02:07", "HLA-A*02:08", "HLA-A*02:09", "HLA-A*02:10", "HLA-A*02:11", "HLA-A*02:12", "HLA-A*02:14",
-             "HLA-A*02:16", "HLA-A*02:17", "HLA-A*02:19", "HLA-A*02:50", "HLA-A*03:01", "HLA-A*03:02", "HLA-A*03:19",
-             "HLA-A*11:01", "HLA-A*11:02", "HLA-A*23:01", "HLA-A*24:01", "HLA-A*24:02", "HLA-A*24:03", "HLA-A*25:01",
-             "HLA-A*26:01", "HLA-A*26:02", "HLA-A*26:03", "HLA-A*29:01", "HLA-A*29:02", "HLA-A*30:01", "HLA-A*30:02",
-             "HLA-A*30:03", "HLA-A*30:04", "HLA-A*31:01", "HLA-A*32:01", "HLA-A*32:07", "HLA-A*32:15", "HLA-A*33:01",
-             "HLA-A*33:03", "HLA-A*66:01", "HLA-A*68:01", "HLA-A*68:02", "HLA-A*68:23", "HLA-A*69:01", "HLA-A*74:01",
-             "HLA-A*80:01", "HLA-B*07:01", "HLA-B*07:02", "HLA-B*08:01", "HLA-B*08:02", "HLA-B*08:03", "HLA-B*12:01",
-             "HLA-B*13:02", "HLA-B*14:01", "HLA-B*14:02", "HLA-B*15:01", "HLA-B*15:02", "HLA-B*15:03", "HLA-B*15:08",
-             "HLA-B*15:09", "HLA-B*15:10", "HLA-B*15:13", "HLA-B*15:16", "HLA-B*15:17", "HLA-B*15:42", "HLA-B*18:01",
-             "HLA-B*27:01", "HLA-B*27:02", "HLA-B*27:03", "HLA-B*27:04", "HLA-B*27:05", "HLA-B*27:06", "HLA-B*27:09",
-             "HLA-B*27:10", "HLA-B*27:20", "HLA-B*35:01", "HLA-B*35:02", "HLA-B*35:03", "HLA-B*35:08", "HLA-B*37:01",
-             "HLA-B*38:01", "HLA-B*39:01", "HLA-B*39:06", "HLA-B*39:09", "HLA-B*39:10", "HLA-B*40:01", "HLA-B*40:02",
-             "HLA-B*40:13", "HLA-B*41:03", "HLA-B*41:04", "HLA-B*42:01", "HLA-B*42:02", "HLA-B*44:01", "HLA-B*44:02",
-             "HLA-B*44:03", "HLA-B*44:05", "HLA-B*45:01", "HLA-B*45:06", "HLA-B*46:01", "HLA-B*48:01", "HLA-B*51:01",
-             "HLA-B*51:02", "HLA-B*52:01", "HLA-B*53:01", "HLA-B*54:01", "HLA-B*55:01", "HLA-B*55:02", "HLA-B*56:01",
-             "HLA-B*57:01", "HLA-B*57:02", "HLA-B*57:03", "HLA-B*58:01", "HLA-B*58:02", "HLA-B*60:01", "HLA-B*61:01",
-             "HLA-B*62:01", "HLA-B*73:01", "HLA-B*81:01", "HLA-B*83:01", "H-2-Db", "H-2-Dd", "H-2-Dk",
-             "H-2-Kb", "H-2-Kd", "H-2-Kk", "H-2-Ld", "H-2-Lq"])
-        __supported_length = frozenset([5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15])
         __name = "mhcnuggets-class-1"
         __version = "2.0"
+        __supported_length = frozenset([5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15])
+        __allele_import_name = f"{__name}_{__version}".replace('-', '_').replace('.', '_')
+        __alleles = getattr(__import__("epytope.Data.supportedAlleles.ann." + __allele_import_name,
+                                       fromlist=[__allele_import_name])
+                            , __allele_import_name)
 
-        # the interface defines three class properties
         @property
         def name(self):
             # returns the name of the predictor
@@ -267,45 +250,28 @@ try:
             Rohit Bhattacharya, Ashok Sivakumar, Collin Tokheim, Violeta Beleva Guthrie, Valsamo Anagnostou,
             Victor E. Velculescu, Rachel Karchin (2017) bioRxiv
         """
-        __alleles = frozenset(["HLA-A*01:01", "HLA-A*02:01", "HLA-A*02:02", "HLA-A*02:03", "HLA-A*02:05", "HLA-A*02:06", "HLA-A*02:07",
-                               "HLA-A*02:11", "HLA-A*02:12", "HLA-A*02:16", "HLA-A*02:17", "HLA-A*02:19", "HLA-A*02:50", "HLA-A*03:01",
-                               "HLA-A*03:19", "HLA-A*11:01", "HLA-A*23:01", "HLA-A*24:01", "HLA-A*24:02", "HLA-A*24:03", "HLA-A*25:01",
-                               "HLA-A*26:01", "HLA-A*26:02", "HLA-A*26:03", "HLA-A*29:02", "HLA-A*30:01", "HLA-A*30:02", "HLA-A*31:01",
-                               "HLA-A*32:01", "HLA-A*32:07", "HLA-A*32:15", "HLA-A*33:01", "HLA-A*66:01", "HLA-A*68:01", "HLA-A*68:02",
-                               "HLA-A*68:23", "HLA-A*69:01", "HLA-A*80:01", "HLA-B*07:01", "HLA-B*07:02", "HLA-B*08:01", "HLA-B*08:02",
-                               "HLA-B*08:03", "HLA-B*14:01", "HLA-B*14:02", "HLA-B*15:01", "HLA-B*15:02", "HLA-B*15:03", "HLA-B*15:09",
-                               "HLA-B*15:16", "HLA-B*15:17", "HLA-B*15:42", "HLA-B*18:01", "HLA-B*27:01", "HLA-B*27:02", "HLA-B*27:03",
-                               "HLA-B*27:04", "HLA-B*27:05", "HLA-B*27:06", "HLA-B*27:09", "HLA-B*27:20", "HLA-B*35:01", "HLA-B*35:03",
-                               "HLA-B*35:08", "HLA-B*37:01", "HLA-B*38:01", "HLA-B*39:01", "HLA-B*39:06", "HLA-B*40:01", "HLA-B*40:02",
-                               "HLA-B*40:13", "HLA-B*42:01", "HLA-B*44:01", "HLA-B*44:02", "HLA-B*44:03", "HLA-B*45:01", "HLA-B*45:06",
-                               "HLA-B*46:01", "HLA-B*48:01", "HLA-B*51:01", "HLA-B*53:01", "HLA-B*54:01", "HLA-B*57:01", "HLA-B*57:03",
-                               "HLA-B*58:01", "HLA-B*58:02", "HLA-B*62:01", "HLA-B*73:01", "HLA-B*81:01", "HLA-B*83:01", "HLA-C*03:03",
-                               "HLA-C*03:04", "HLA-C*04:01", "HLA-C*05:01", "HLA-C*06:02", "HLA-C*07:01", "HLA-C*07:02", "HLA-C*08:01",
-                               "HLA-C*08:02", "HLA-C*12:03", "HLA-C*14:02", "HLA-C*15:02", "HLA-E*01:03", "H-2-Db", "H-2-Dd", "H-2-Kb",
-                               "H-2-Kd", "H-2-Kk", "H-2-Ld"])
-        __supported_length = frozenset([5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15])
         __name = "mhcnuggets-class-1"
         __version = "2.3.2"
+        __supported_length = frozenset([5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15])
+        __allele_import_name = f"{__name}_{__version}".replace('-', '_').replace('.', '_')
+        __alleles = getattr(__import__("epytope.Data.supportedAlleles.ann." + __allele_import_name,
+                                       fromlist=[__allele_import_name])
+                            , __allele_import_name)
 
-        # the interface defines three class properties
         @property
         def name(self):
-            # returns the name of the predictor
             return self.__name
 
         @property
         def supportedAlleles(self):
-            # returns the supported alleles as strings (without the HLA prefix)
             return self.__alleles
 
         @property
         def supportedLength(self):
-            # returns the supported epitope lengths as iterable
             return self.__supported_length
 
         @property
         def version(self):
-            # returns the version of the predictor
             return self.__version
 
         def _represent(self, allele):
@@ -321,6 +287,19 @@ try:
             else:
                 return "%s-%s%s:%s" % (allele.organism, allele.locus, allele.supertype, allele.subtype)
 
+        def convert_alleles(self, alleles):
+            """
+            Converts :class:`~epytope.Core.Allele.Allele` into the internal :class:`~epytope.Core.Allele.Allele` representation
+            of the predictor and returns a string representation
+
+            :param alleles: The :class:`~epytope.Core.Allele.Allele` for which the internal predictor representation is
+                            needed
+            :type alleles: :class:`~epytope.Core.Allele.Allele`
+            :return: Returns a string representation of the input :class:`~epytope.Core.Allele.Allele`
+            :rtype: list(str)
+            """
+            return [self._represent(a) for a in alleles]
+
         # Converts the internal mhcnuggets-class-1 HLA representation back into a epytope representation
         def revert_allele_repr(self, name):
             if name.startswith("H-2-"):
@@ -344,66 +323,28 @@ try:
             Rohit Bhattacharya, Ashok Sivakumar, Collin Tokheim, Violeta Beleva Guthrie, Valsamo Anagnostou,
             Victor E. Velculescu, Rachel Karchin (2017) bioRxiv
         """
-        __alleles = frozenset(["HLA-DPA1*01:03-DPB1*02:01", "HLA-DPA1*01:03-DPB1*03:01", "HLA-DPA1*01:03-DPB1*04:01",
-                               "HLA-DPA1*01:03-DPB1*04:02", "HLA-DPA1*02:01-DPB1*01:01", "HLA-DPA1*02:01-DPB1*05:01",
-                               "HLA-DPA1*02:02-DPB1*05:01", "HLA-DPA1*03:01-DPB1*04:02", "HLA-DPB1*01:01",
-                               "HLA-DPB1*02:01", "HLA-DPB1*03:01", "HLA-DPB1*04:01", "HLA-DPB1*04:02", "HLA-DPB1*05:01",
-                               "HLA-DPB1*09:01", "HLA-DPB1*11:01", "HLA-DPB1*14:01", "HLA-DPB1*20:01", "HLA-DQA1*01:01",
-                               "HLA-DQA1*01:01-DQB1*05:01", "HLA-DQA1*01:01-DQB1*05:03", "HLA-DQA1*01:02",
-                               "HLA-DQA1*01:02-DQB1*05:01", "HLA-DQA1*01:02-DQB1*05:02", "HLA-DQA1*01:02-DQB1*06:02",
-                               "HLA-DQA1*01:02-DQB1*06:04", "HLA-DQA1*01:03-DQB1*03:02", "HLA-DQA1*01:03-DQB1*06:01",
-                               "HLA-DQA1*01:03-DQB1*06:03", "HLA-DQA1*01:04-DQB1*05:03", "HLA-DQA1*02:01-DQB1*02:01",
-                               "HLA-DQA1*02:01-DQB1*02:02", "HLA-DQA1*02:01-DQB1*03:01", "HLA-DQA1*02:01-DQB1*03:03",
-                               "HLA-DQA1*02:01-DQB1*04:02", "HLA-DQA1*03:01", "HLA-DQA1*03:01-DQB1*02:01",
-                               "HLA-DQA1*03:01-DQB1*03:01", "HLA-DQA1*03:01-DQB1*03:02", "HLA-DQA1*03:01-DQB1*04:01",
-                               "HLA-DQA1*03:02-DQB1*03:01", "HLA-DQA1*03:02-DQB1*03:03", "HLA-DQA1*03:02-DQB1*04:01",
-                               "HLA-DQA1*03:03-DQB1*04:02", "HLA-DQA1*04:01-DQB1*04:02", "HLA-DQA1*05:01",
-                               "HLA-DQA1*05:01-DQB1*02:01", "HLA-DQA1*05:01-DQB1*03:01", "HLA-DQA1*05:01-DQB1*03:02",
-                               "HLA-DQA1*05:01-DQB1*03:03", "HLA-DQA1*05:01-DQB1*04:02", "HLA-DQA1*05:05-DQB1*03:01",
-                               "HLA-DQA1*06:01-DQB1*04:02", "HLA-DQB1*02:01", "HLA-DQB1*02:02", "HLA-DQB1*03:01",
-                               "HLA-DQB1*03:02", "HLA-DQB1*03:19", "HLA-DQB1*04:02", "HLA-DQB1*05:01", "HLA-DQB1*05:02",
-                               "HLA-DQB1*05:03", "HLA-DQB1*06:02", "HLA-DQB1*06:03", "HLA-DQB1*06:04",
-                               "HLA-DRA0*10:1-DRB1*01:01", "HLA-DRA0*10:1-DRB1*03:01", "HLA-DRA0*10:1-DRB1*04:01",
-                               "HLA-DRA0*10:1-DRB1*04:04", "HLA-DRA0*10:1-DRB1*07:01", "HLA-DRA0*10:1-DRB1*08:01",
-                               "HLA-DRA0*10:1-DRB1*09:01", "HLA-DRA0*10:1-DRB1*11:01", "HLA-DRA0*10:1-DRB1*13:01",
-                               "HLA-DRA0*10:1-DRB1*14:54", "HLA-DRA0*10:1-DRB1*15:01", "HLA-DRA0*10:1-DRB3*01:01",
-                               "HLA-DRA0*10:1-DRB3*02:02", "HLA-DRA0*10:1-DRB3*03:01", "HLA-DRA0*10:1-DRB4*01:03",
-                               "HLA-DRA0*10:1-DRB5*01:01", "HLA-DRB1*01:01", "HLA-DRB1*01:02", "HLA-DRB1*01:03",
-                               "HLA-DRB1*03:01", "HLA-DRB1*03:02", "HLA-DRB1*03:03", "HLA-DRB1*03:04", "HLA-DRB1*03:05",
-                               "HLA-DRB1*04:01", "HLA-DRB1*04:02", "HLA-DRB1*04:03", "HLA-DRB1*04:04", "HLA-DRB1*04:05",
-                               "HLA-DRB1*04:06", "HLA-DRB1*04:07", "HLA-DRB1*04:11", "HLA-DRB1*07:01", "HLA-DRB1*08:01",
-                               "HLA-DRB1*08:02", "HLA-DRB1*08:03", "HLA-DRB1*08:04", "HLA-DRB1*09:01", "HLA-DRB1*10:01",
-                               "HLA-DRB1*11:01", "HLA-DRB1*11:02", "HLA-DRB1*11:03", "HLA-DRB1*11:04", "HLA-DRB1*12:01",
-                               "HLA-DRB1*12:02", "HLA-DRB1*13:01", "HLA-DRB1*13:02", "HLA-DRB1*13:03", "HLA-DRB1*13:04",
-                               "HLA-DRB1*13:05", "HLA-DRB1*14:01", "HLA-DRB1*14:02", "HLA-DRB1*15:01", "HLA-DRB1*15:02",
-                               "HLA-DRB1*15:03", "HLA-DRB1*16:01", "HLA-DRB1*16:02", "HLA-DRB3*01:01", "HLA-DRB3*02:02",
-                               "HLA-DRB3*03:01", "HLA-DRB4*01:01", "HLA-DRB4*01:03", "HLA-DRB5*01:01", "HLA-DRB5*01:02",
-                               "H-2-Iab", "H-2-Iad", "H-2-Iak", "H-2-Iap", "H-2-Iaq",
-                               "H-2-Iar", "H-2-Ias", "H-2-Iau", "H-2-Ieb", "H-2-Ied",
-                               "H-2-Iek", "H-2-Iep", "H-2-Ier"])
-        __supported_length = frozenset([5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25])
         __name = "mhcnuggets-class-2"
         __version = "2.0"
+        __supported_length = frozenset([5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25])
+        __allele_import_name = f"{__name}_{__version}".replace('-', '_').replace('.', '_')
+        __alleles = getattr(__import__("epytope.Data.supportedAlleles.ann." + __allele_import_name,
+                                       fromlist=[__allele_import_name])
+                            , __allele_import_name)
 
-        # the interface defines three class properties
         @property
         def name(self):
-            # returns the name of the predictor
             return self.__name
 
         @property
         def supportedAlleles(self):
-            # returns the supported alleles as strings (without the HLA prefix)
             return self.__alleles
 
         @property
         def supportedLength(self):
-            # returns the supported epitope lengths as iterable
             return self.__supported_length
 
         @property
         def version(self):
-            # returns the version of the predictor
             return self.__version
 
         def _represent(self, allele):
@@ -550,67 +491,29 @@ try:
             Rohit Bhattacharya, Ashok Sivakumar, Collin Tokheim, Violeta Beleva Guthrie, Valsamo Anagnostou,
             Victor E. Velculescu, Rachel Karchin (2017) bioRxiv
         """
-        __alleles = frozenset(["HLA-DPA1*01:03-DPB1*02:01", "HLA-DPA1*01:03-DPB1*03:01", "HLA-DPA1*01:03-DPB1*04:01",
-                               "HLA-DPA1*01:03-DPB1*04:02", "HLA-DPA1*02:01-DPB1*01:01", "HLA-DPA1*02:01-DPB1*05:01",
-                               "HLA-DPA1*02:02-DPB1*05:01", "HLA-DPA1*03:01-DPB1*04:02", "HLA-DPB1*01:01",
-                               "HLA-DPB1*02:01", "HLA-DPB1*03:01", "HLA-DPB1*04:01",
-                               "HLA-DPB1*04:02", "HLA-DPB1*05:01", "HLA-DPB1*09:01",
-                               "HLA-DPB1*11:01", "HLA-DPB1*14:01", "HLA-DPB1*20:01",
-                               "HLA-DQA1*01:01-DQB1*05:01", "HLA-DQA1*01:02-DQB1*05:01", "HLA-DQA1*01:02-DQB1*05:02",
-                               "HLA-DQA1*01:02-DQB1*06:02", "HLA-DQA1*01:02-DQB1*06:04", "HLA-DQA1*01:03-DQB1*06:01",
-                               "HLA-DQA1*01:03-DQB1*06:03", "HLA-DQA1*01:04-DQB1*05:03", "HLA-DQA1*02:01-DQB1*02:01",
-                               "HLA-DQA1*02:01-DQB1*02:02", "HLA-DQA1*02:01-DQB1*03:01", "HLA-DQA1*02:01-DQB1*03:03",
-                               "HLA-DQA1*02:01-DQB1*04:02", "HLA-DQA1*03:01-DQB1*02:01", "HLA-DQA1*03:01-DQB1*03:01",
-                               "HLA-DQA1*03:01-DQB1*03:02", "HLA-DQA1*03:01-DQB1*04:01", "HLA-DQA1*03:02-DQB1*03:01",
-                               "HLA-DQA1*03:02-DQB1*04:01", "HLA-DQA1*03:03-DQB1*04:02", "HLA-DQA1*04:01-DQB1*04:02",
-                               "HLA-DQA1*05:01-DQB1*02:01", "HLA-DQA1*05:01-DQB1*03:01", "HLA-DQA1*05:01-DQB1*03:02",
-                               "HLA-DQA1*05:01-DQB1*03:03", "HLA-DQA1*05:01-DQB1*04:02", "HLA-DQA1*05:05-DQB1*03:01",
-                               "HLA-DQA1*06:01-DQB1*04:02", "HLA-DQB1*02:01", "HLA-DQB1*02:02",
-                               "HLA-DQB1*03:01", "HLA-DQB1*03:02", "HLA-DQB1*03:19",
-                               "HLA-DQB1*04:02", "HLA-DQB1*05:01", "HLA-DQB1*05:02",
-                               "HLA-DQB1*05:03", "HLA-DQB1*06:02", "HLA-DRB1*01:01",
-                               "HLA-DRB1*01:02", "HLA-DRB1*01:03", "HLA-DRB1*03:01",
-                               "HLA-DRB1*03:02", "HLA-DRB1*03:03", "HLA-DRB1*03:05",
-                               "HLA-DRB1*04:01", "HLA-DRB1*04:02", "HLA-DRB1*04:03",
-                               "HLA-DRB1*04:04", "HLA-DRB1*04:05", "HLA-DRB1*04:06",
-                               "HLA-DRB1*04:07", "HLA-DRB1*04:11", "HLA-DRB1*07:01",
-                               "HLA-DRB1*08:01", "HLA-DRB1*08:02", "HLA-DRB1*08:03",
-                               "HLA-DRB1*09:01", "HLA-DRB1*10:01", "HLA-DRB1*11:01",
-                               "HLA-DRB1*11:02", "HLA-DRB1*11:03", "HLA-DRB1*11:04",
-                               "HLA-DRB1*12:01", "HLA-DRB1*12:02", "HLA-DRB1*13:01",
-                               "HLA-DRB1*13:02", "HLA-DRB1*13:03", "HLA-DRB1*13:04",
-                               "HLA-DRB1*14:01", "HLA-DRB1*14:02", "HLA-DRB1*15:01",
-                               "HLA-DRB1*15:02", "HLA-DRB1*15:03", "HLA-DRB1*16:01",
-                               "HLA-DRB1*16:02", "HLA-DRB3*01:01", "HLA-DRB3*02:02",
-                               "HLA-DRB3*03:01", "HLA-DRB4*01:01", "HLA-DRB4*01:03",
-                               "HLA-DRB5*01:01", "HLA-DRB5*01:02", "H-2-Iab",
-                               "H-2-Iad", "H-2-Iak", "H-2-Iap",
-                               "H-2-Iaq", "H-2-Iar", "H-2-Ias",
-                               "H-2-Iau", "H-2-Ieb", "H-2-Ied",
-                               "H-2-Iek", "H-2-Iep", "H-2-Ier"])
-        __supported_length = frozenset([5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30])
         __name = "mhcnuggets-class-2"
         __version = "2.3.2"
+        __supported_length = frozenset(
+            [5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30])
+        __allele_import_name = f"{__name}_{__version}".replace('-', '_').replace('.', '_')
+        __alleles = getattr(__import__("epytope.Data.supportedAlleles.ann." + __allele_import_name,
+                                       fromlist=[__allele_import_name])
+                            , __allele_import_name)
 
-        # the interface defines three class properties
         @property
         def name(self):
-            # returns the name of the predictor
             return self.__name
 
         @property
         def supportedAlleles(self):
-            # returns the supported alleles as strings (without the HLA prefix)
             return self.__alleles
 
         @property
         def supportedLength(self):
-            # returns the supported epitope lengths as iterable
             return self.__supported_length
 
         @property
         def version(self):
-            # returns the version of the predictor
             return self.__version
 
         def _represent(self, allele):
@@ -630,6 +533,19 @@ try:
             else:
                 return "%s-%s%s:%s" % (allele.organism, allele.locus, allele.supertype, allele.subtype)
 
+        def convert_alleles(self, alleles):
+            """
+            Converts :class:`~epytope.Core.Allele.Allele` into the internal :class:`~epytope.Core.Allele.Allele` representation
+            of the predictor and returns a string representation
+
+            :param alleles: The :class:`~epytope.Core.Allele.Allele` for which the internal predictor representation is
+                            needed
+            :type alleles: :class:`~epytope.Core.Allele.Allele`
+            :return: Returns a string representation of the input :class:`~epytope.Core.Allele.Allele`
+            :rtype: list(str)
+            """
+            return [self._represent(a) for a in alleles]
+
         # Converts the internal mhcnuggets-class-2 representation back into a epytope representation
         def revert_allele_repr(self, name):
             if name.startswith("H-2-"):
@@ -659,43 +575,28 @@ try:
              "MHCflurry: Open-Source Class I MHC Binding Affinity Prediction," Cell Systems, 2018.
               Available at: https://www.cell.com/cell-systems/fulltext/S2405-4712(18)30232-1.
         """
-        __alleles = frozenset(
-            ["HLA-A*01:01", "HLA-A*02:01", "HLA-A*02:02", "HLA-A*02:03", "HLA-A*02:05", "HLA-A*02:06", "HLA-A*02:07",
-             "HLA-A*02:11", "HLA-A*02:12", "HLA-A*02:16", "HLA-A*02:17", "HLA-A*02:19", "HLA-A*02:50", "HLA-A*03:01",
-             "HLA-A*11:01", "HLA-A*23:01", "HLA-A*24:02", "HLA-A*24:03", "HLA-A*25:01", "HLA-A*26:01", "HLA-A*26:02",
-             "HLA-A*26:03", "HLA-A*29:02", "HLA-A*30:01", 'HLA-A*30:02', "HLA-A*31:01", "HLA-A*32:01", "HLA-A*33:01",
-             "HLA-A*66:01", "HLA-A*68:01", "HLA-A*68:02", "HLA-A*68:23", "HLA-A*69:01", "HLA-A*80:01", "HLA-B*07:01",
-             "HLA-B*07:02", "HLA-B*08:01", "HLA-B*08:02", "HLA-B*08:03", "HLA-B*14:02", "HLA-B*15:01", "HLA-B*15:02",
-             "HLA-B*15:03", "HLA-B*15:09", "HLA-B*15:17", "HLA-B*18:01", "HLA-B*27:02", "HLA-B*27:03", "HLA-B*27:04",
-             "HLA-B*27:05", "HLA-B*27:06", "HLA-B*35:01", "HLA-B*35:03", "HLA-B*37:01", "HLA-B*38:01", "HLA-B*39:01",
-             "HLA-B*39:06", "HLA-B*40:01", "HLA-B*40:02", "HLA-B*42:01", "HLA-B*44:02", "HLA-B*44:03", "HLA-B*45:01",
-             "HLA-B*46:01", "HLA-B*48:01", "HLA-B*51:01", "HLA-B*53:01", "HLA-B*54:01", "HLA-B*57:01", "HLA-B*58:01",
-             "HLA-B*83:01", "HLA-C*03:03", "HLA-C*04:01", "HLA-C*05:01", "HLA-C*06:02", "HLA-C*07:02", "HLA-C*08:02",
-             "HLA-C*12:03", "HLA-C*14:02", "HLA-C*15:02", "H-2-Db", "H-2-Dd", "H-2-Kb", "H-2-Kd",
-             "H-2-Kk", "H-2-Ld"])
-        __supported_length = frozenset([8, 9, 10, 11, 12, 13, 14, 15])
         __name = "mhcflurry"
         __version = "1.2.2"
+        __supported_length = frozenset([8, 9, 10, 11, 12, 13, 14, 15])
+        __allele_import_name = f"{__name}_{__version}".replace('.', '_')
+        __alleles = getattr(__import__("epytope.Data.supportedAlleles.ann." + __allele_import_name,
+                                       fromlist=[__allele_import_name])
+                            , __allele_import_name)
 
-        # the interface defines three class properties
         @property
         def name(self):
-            # returns the name of the predictor
             return self.__name
 
         @property
         def supportedAlleles(self):
-            # returns the supported alleles as strings (without the HLA prefix)
             return self.__alleles
 
         @property
         def supportedLength(self):
-            # returns the supported epitope lengths as iterable
             return self.__supported_length
 
         @property
         def version(self):
-            # returns the version of the predictor
             return self.__version
 
         def _represent(self, allele):
@@ -821,49 +722,28 @@ try:
              "MHCflurry: Open-Source Class I MHC Binding Affinity Prediction," Cell Systems, 2018.
               Available at: https://www.cell.com/cell-systems/fulltext/S2405-4712(18)30232-1.
         """
-        # retrieved with `mhcflurry-predict --list-supported-alleles`
-        __alleles = frozenset(["HLA-A*01:01", "HLA-A*02:01", "HLA-A*02:02", "HLA-A*02:03", "HLA-A*02:05",
-                               "HLA-A*02:06", "HLA-A*02:07", "HLA-A*02:11", "HLA-A*02:12", "HLA-A*02:16",
-                               "HLA-A*02:17", "HLA-A*02:19", "HLA-A*02:50", "HLA-A*03:01", "HLA-A*11:01",
-                               "HLA-A*23:01", "HLA-A*24:02", "HLA-A*24:03", "HLA-A*25:01", "HLA-A*26:01",
-                               "HLA-A*26:02", "HLA-A*26:03", "HLA-A*29:02", "HLA-A*30:01", "HLA-A*30:02",
-                               "HLA-A*31:01", "HLA-A*32:01", "HLA-A*33:01", "HLA-A*66:01", "HLA-A*68:01",
-                               "HLA-A*68:02", "HLA-A*68:23", "HLA-A*69:01", "HLA-A*80:01", "HLA-B*07:01",
-                               "HLA-B*07:02", "HLA-B*08:01", "HLA-B*08:02", "HLA-B*08:03", "HLA-B*14:02",
-                               "HLA-B*15:01", "HLA-B*15:02", "HLA-B*15:03", "HLA-B*15:09", "HLA-B*15:17",
-                               "HLA-B*18:01", "HLA-B*27:02", "HLA-B*27:03", "HLA-B*27:04", "HLA-B*27:05",
-                               "HLA-B*27:06", "HLA-B*35:01", "HLA-B*35:03", "HLA-B*37:01", "HLA-B*38:01",
-                               "HLA-B*39:01", "HLA-B*39:06", "HLA-B*40:01", "HLA-B*40:02", "HLA-B*42:01",
-                               "HLA-B*44:02", "HLA-B*44:03", "HLA-B*45:01", "HLA-B*46:01", "HLA-B*48:01",
-                               "HLA-B*51:01", "HLA-B*53:01", "HLA-B*54:01", "HLA-B*57:01", "HLA-B*58:01",
-                               "HLA-B*83:01", "HLA-C*03:03", "HLA-C*04:01", "HLA-C*05:01", "HLA-C*06:02",
-                               "HLA-C*07:02", "HLA-C*08:02", "HLA-C*12:03", "HLA-C*14:02", "HLA-C*15:02",
-                               "H-2-Db", "H-2-Dd", "H-2-Kb", "H-2-Kd", "H-2-Kk",
-                               "H-2-Ld"])
-        # retrieved with `mhcflurry-predict --list-supported-peptide-lengths`
-        __supported_length = frozenset([8, 9, 10, 11, 12, 13, 14, 15])
         __name = "mhcflurry"
         __version = "1.4.3"
+        __supported_length = frozenset([8, 9, 10, 11, 12, 13, 14, 15])
+        __allele_import_name = f"{__name}_{__version}".replace('.', '_')
+        __alleles = getattr(__import__("epytope.Data.supportedAlleles.ann." + __allele_import_name,
+                                       fromlist=[__allele_import_name])
+                            , __allele_import_name)
 
-        # the interface defines three class properties
         @property
         def name(self):
-            # returns the name of the predictor
             return self.__name
 
         @property
         def supportedAlleles(self):
-            # returns the supported alleles as strings (without the HLA prefix)
             return self.__alleles
 
         @property
         def supportedLength(self):
-            # returns the supported epitope lengths as iterable
             return self.__supported_length
 
         @property
         def version(self):
-            # returns the version of the predictor
             return self.__version
 
         def _represent(self, allele):
@@ -879,6 +759,19 @@ try:
             else:
                 return "%s-%s*%s:%s" % (allele.organism, allele.locus, allele.supertype, allele.subtype)
 
+        def convert_alleles(self, alleles):
+            """
+            Converts :class:`~epytope.Core.Allele.Allele` into the internal :class:`~epytope.Core.Allele.Allele` representation
+            of the predictor and returns a string representation
+
+            :param alleles: The :class:`~epytope.Core.Allele.Allele` for which the internal predictor representation is
+                            needed
+            :type alleles: :class:`~epytope.Core.Allele.Allele`
+            :return: Returns a string representation of the input :class:`~epytope.Core.Allele.Allele`
+            :rtype: list(str)
+            """
+            return [self._represent(a) for a in alleles]
+
         # Converts the internal MHCFlurry representation back into a epytope representation
         def revert_allele_repr(self, name):
             if name.startswith("H-2-"):
